### 0.13.3 {small}`2025-10-21`

```{rubric} Features
```
* Add Multi-GPU support for `pp.neighbors` (requires `cuvs >= 25.10`) with the new algorithms `mg_ivfflat`, `mg_ivfpq`, and `all_neighbors`. {pr}`465` {smaller}`S Dicks`

```{rubric} Performance
```
* make `dcg.aucell` faster using a single rank pass algorithm {pr}`448` {smaller}`S Dicks`
* make FDR calculation faster and more scalable offering a new CPU and updated GPU path for `dcg`. {pr}`450` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Updates `tl.embedding_density` to work with `rapids-25.10` {pr}`464` {smaller}`S Dicks`
* Allow for UMAP to run on larger than int32 connectivity graphs{pr}`465` {smaller}`S Dicks`

```{rubric} Misc
```
* Deprecate CUDA-11 and add support for CUDA-13 {pr}`441` {smaller}`S Dicks`
